package com.recordingblogs;

import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Vector;
import javax.swing.*;

/**
 * Standard select dialog
 * 
 * Copyright (c) 2003 Anton Kamenov.  This file and the included source code is the 
 * property of Anton Kamenov.  Under no circumstances will the file and source code be 
 * sold, transferred, modified, or commercially exploited in part or in whole, without 
 * the prior written consent of Anton Kamenov.
 */

public class SelectDialog extends JDialog implements ActionListener
{
	/**
	 * This serial version UID is not used
	 */
	private static final long serialVersionUID = 2004346775385178788L;

	/**
	 * A list box to list all items
	 */
	private JList<String> m_list;
	
	/**
	 * The OK button
	 */
    private JButton m_okButton;
    
    /**
     * The cancel button
     */
    private JButton m_cancelButton;

    /**
     * true, if the user pressed OK; false, otherwise
     */
    private boolean m_OK;
    
    /**
     * The index of the selected item
     */
    private int m_selected;

    /**
     * The one and only constructor
     * @param listData The list of items to be displayed
     */
    public SelectDialog(Vector<String> listData)
    {
        super();
        Action escape = new AbstractAction()
        {
        	static final long serialVersionUID = -1717679756166556296L;
        	
            @Override
			public void actionPerformed(ActionEvent e)
            {
                m_OK = false;
                dispose();
            }
        };
        setTitle("Select");									//$NON-NLS-1$
        setDefaultCloseOperation(DISPOSE_ON_CLOSE);

        GridBagLayout layout = new GridBagLayout();
        GridBagConstraints constraints = new GridBagConstraints();
        getContentPane().setLayout(layout);

        JPanel buttonPanel = new JPanel();
        GridBagLayout buttonLayout = new GridBagLayout();
        GridBagConstraints buttonConstraints = new GridBagConstraints();
        buttonPanel.setLayout(buttonLayout);
        m_okButton = new JButton("OK");					//$NON-NLS-1$
        m_okButton.addActionListener(this);
        buttonConstraints.gridx = 0;
        buttonConstraints.gridy = 0;
        buttonConstraints.insets.right = 5;
        buttonConstraints.anchor = GridBagConstraints.NORTH;
        buttonConstraints.fill = GridBagConstraints.HORIZONTAL;
        buttonLayout.setConstraints(m_okButton, buttonConstraints);
        buttonPanel.add(m_okButton);

        m_cancelButton = new JButton("Cancel");			//$NON-NLS-1$
        m_cancelButton.addActionListener(this);
        m_cancelButton.getInputMap(JComponent.WHEN_IN_FOCUSED_WINDOW).put(KeyStroke.getKeyStroke("ESCAPE"), 	//$NON-NLS-1$
        		"pressed ESCAPE");																				//$NON-NLS-1$
        m_cancelButton.getActionMap().put("pressed ESCAPE", escape);											//$NON-NLS-1$
        buttonConstraints.gridy = 1;
        buttonConstraints.insets.top = 5;
        buttonLayout.setConstraints(m_cancelButton, buttonConstraints);
        buttonPanel.add(m_cancelButton);

        JPanel tempPanel = new JPanel();
        buttonConstraints.weighty = 1.0D;
        buttonConstraints.gridy = 2;
        buttonLayout.setConstraints(tempPanel, buttonConstraints);
        buttonPanel.add(tempPanel);

        m_list = new JList<>();
        m_list.setToolTipText("Select an item");							//$NON-NLS-1$
        m_list.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        m_list.setListData(listData);
        m_list.setBorder(BorderFactory.createLoweredBevelBorder());
        m_list.setPrototypeCellValue("Some prototype cell value      ");	//$NON-NLS-1$

        JScrollPane listScrollPane = new JScrollPane();
        listScrollPane.setViewportView(m_list);
        constraints.insets.left = 5;
        constraints.insets.top = 5;
        constraints.insets.bottom = 5;
        constraints.gridx = 0;
        constraints.gridy = 0;
        constraints.weightx = 1.0D;
        constraints.weighty = 1.0D;
        constraints.fill = GridBagConstraints.BOTH;
        layout.setConstraints(listScrollPane, constraints);
        getContentPane().add(listScrollPane);

        constraints.gridx = 1;
        constraints.weightx = 0.0D;
        constraints.weighty = 0.0D;
        constraints.anchor = GridBagConstraints.NORTH;
        constraints.fill = GridBagConstraints.VERTICAL;
        layout.setConstraints(buttonPanel, constraints);

        getContentPane().add(buttonPanel);

        m_OK = false;
        m_selected = 0;
        if(listData.size() <= 0)
            m_list.setEnabled(false);
        else
            m_list.setSelectedIndex(0);

        pack();
    	m_list.ensureIndexIsVisible(m_list.getSelectedIndex());
    }

    /**
     * Get whether the user pressed OK or not
     * @return true, if the user pressed OK; false, otherwise
     */
    public boolean getOK()
    {
        return m_OK;
    }

    /**
     * Get the index of the selected item
     * @return The index of the selected item
     */
    public int getSelected()
    {
        return m_selected;
    }

    /**
     * Capture action events (from the OK or Cancel button)
     * @param e The action event
     */
    @Override
	public void actionPerformed(ActionEvent e)
    {
        if(e.getSource() == m_okButton)
        {
            m_OK = true;
            m_selected = m_list.getSelectedIndex();
            dispose();
        }
        else if(e.getSource() == m_cancelButton)
        {
            m_OK = false;
            dispose();
        }
    }
}
