package com.recordingblogs;

import java.awt.*;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.File;
import javax.swing.*;

/**
 * Dialog to choose a wave file
 * 
 * Copyright (c) 2003 Anton Kamenov.  This file and the included source code is the 
 * property of Anton Kamenov.  Under no circumstances will the file and source code be 
 * sold, transferred, modified, or commercially exploited in part or in whole, without 
 * the prior written consent of Anton Kamenov.
 */

public class WaveFileDialog extends JDialog implements ActionListener
{
	/**
	 * This serial version UID is not used
	 */
	static final long serialVersionUID = 4264274760684661007L;
	
	/**
	 * The name of the file
	 */
    private JTextField m_fileName;
    
    /**
     * A button to browse for files
     */
    private JButton m_browseButton;

    /**
     * The OK button
     */
    private JButton m_okButton;
    
    /**
     * The Cancel button
     */
    private JButton m_cancelButton;
    
    /**
     * true, if the user pressed OK; false, otherwise
     */
    private boolean m_ok;

    /**
     * The one and only constructor
     */
    public WaveFileDialog()
    {
        super();
        setTitle("Wave File");	//$NON-NLS-1$
        
        // handle the user pressing escape
        Action escape = new AbstractAction()
        {
        	/**
        	 * This serial version UID is not used
        	 */
        	static final long serialVersionUID = 3737667241120682205L;
        	
        	/**
        	 * Handle escape as a Cancel
        	 */
            @Override
			public void actionPerformed(ActionEvent e)
            {
                m_ok = false;
                dispose();
            }
        };

        m_ok = false;

        GridBagLayout layout = new GridBagLayout();
        GridBagConstraints constraints = new GridBagConstraints();
        getContentPane().setLayout(layout);

        JPanel titlesPane = new JPanel();
        GridBagLayout titlesLayout = new GridBagLayout();
        GridBagConstraints titlesConstraints = new GridBagConstraints();
        titlesPane.setLayout(titlesLayout);

        JLabel fileLabel = new JLabel("File: ");	//$NON-NLS-1$
        titlesConstraints.gridx = 0;
        titlesConstraints.gridy = 0;
        titlesConstraints.weightx = 0.0D;
        titlesConstraints.weighty = 1.0D;
        titlesConstraints.anchor = GridBagConstraints.NORTHWEST;
        titlesConstraints.fill = GridBagConstraints.HORIZONTAL;
        titlesLayout.setConstraints(fileLabel, titlesConstraints);
        titlesPane.add(fileLabel);

        m_fileName = new JTextField(20);
        m_fileName.setToolTipText("Enter a new file name");	//$NON-NLS-1$
        titlesConstraints.gridx = 1;
        titlesConstraints.weightx = 1.0D;
        titlesConstraints.insets.left = 5;
        titlesLayout.setConstraints(m_fileName, titlesConstraints);
        titlesPane.add(m_fileName);

        m_browseButton = new JButton("Browse");	//$NON-NLS-1$
        m_browseButton.addActionListener(this);
        m_browseButton.setToolTipText("Click to browse for a specific file");	//$NON-NLS-1$
        titlesConstraints.gridx = 2;
        titlesConstraints.weightx = 0.0D;
        titlesLayout.setConstraints(m_browseButton, titlesConstraints);
        titlesPane.add(m_browseButton);

        constraints.gridx = 0;
        constraints.gridy = 0;
        constraints.weightx = 1.0D;
        constraints.weighty = 0.0D;
        constraints.anchor = GridBagConstraints.NORTHWEST;
        constraints.fill = GridBagConstraints.HORIZONTAL;
        constraints.insets.top = 5;
        constraints.insets.left = 5;
        layout.setConstraints(titlesPane, constraints);
        getContentPane().add(titlesPane);

        JPanel okPane = new JPanel();
        GridBagLayout okLayout = new GridBagLayout();
        GridBagConstraints okConstraints = new GridBagConstraints();
        okPane.setLayout(okLayout);

        m_okButton = new JButton("OK");	//$NON-NLS-1$
        m_okButton.addActionListener(this);
        okConstraints.gridx = 0;
        okConstraints.gridy = 0;
        okConstraints.weightx = 1.0D;
        okConstraints.weighty = 1.0D;
        okConstraints.fill = GridBagConstraints.HORIZONTAL;
        okConstraints.anchor = GridBagConstraints.NORTHWEST;
        okLayout.setConstraints(m_okButton, okConstraints);
        okPane.add(m_okButton);

        constraints.gridx = 1;
        constraints.weightx = 0.0D;
        constraints.anchor = GridBagConstraints.NORTHWEST;
        constraints.fill = GridBagConstraints.HORIZONTAL;
        constraints.insets.right = 5;
        layout.setConstraints(okPane, constraints);
        getContentPane().add(okPane);

        JPanel cancelPane = new JPanel();
        GridBagLayout cancelLayout = new GridBagLayout();
        GridBagConstraints cancelConstraints = new GridBagConstraints();
        cancelPane.setLayout(cancelLayout);

        m_cancelButton = new JButton("Cancel");	//$NON-NLS-1$
        m_cancelButton.addActionListener(this);
        m_cancelButton.getInputMap(JComponent.WHEN_IN_FOCUSED_WINDOW).put(KeyStroke.getKeyStroke("ESCAPE"),	//$NON-NLS-1$
        		"pressed ESCAPE");	//$NON-NLS-1$
        m_cancelButton.getActionMap().put("pressed ESCAPE", escape);	//$NON-NLS-1$
        cancelConstraints.gridx = 0;
        cancelConstraints.gridy = 0;
        cancelConstraints.weightx = 1.0D;
        cancelConstraints.weighty = 0.0D;
        cancelConstraints.fill = GridBagConstraints.HORIZONTAL;
        cancelConstraints.anchor = GridBagConstraints.NORTHWEST;
        cancelLayout.setConstraints(m_cancelButton, cancelConstraints);
        cancelPane.add(m_cancelButton);

        JPanel emptyPane = new JPanel();
        cancelConstraints.gridy = 1;
        cancelConstraints.weighty = 1.0D;
        cancelLayout.setConstraints(emptyPane, cancelConstraints);
        cancelPane.add(emptyPane);

        constraints.gridy = 1;
        constraints.weighty = 1.0D;
        constraints.insets.bottom = 5;
        constraints.fill = GridBagConstraints.BOTH;
        layout.setConstraints(cancelPane, constraints);
        getContentPane().add(cancelPane);

        pack();
    }

    /**
     * Get whether the user pressed OK
     * @return true, if the user pressed OK; false, otherwise
     */
    public boolean getOK()
    {
        return m_ok;
    }

    /**
     * Get the name of the file that the user chose (full name, including path)
     * @return The name of the file
     */
    public JTextField getFileName()
    {
        return m_fileName;
    }

    /**
     * Capture the user pressing the three buttons
     */
    @Override
	public void actionPerformed(ActionEvent e)
    {
        if (e.getSource() == m_okButton)
        {
            m_ok = true;
            dispose();
        }
        else if(e.getSource() == m_cancelButton)
        {
            m_ok = false;
            dispose();
        }
        else if(e.getSource() == m_browseButton)
        {
            JFileChooser fc = new JFileChooser();
            fc.setCurrentDirectory(new File(".." + File.separator));	//$NON-NLS-1$
            int returnVal = fc.showOpenDialog(this);
            if(returnVal == 0)
            {
                File file = fc.getSelectedFile();
                m_fileName.setText(file.getPath());
            }
        }
    }
}
